@@ -61,7 +61,7 @@ This application implements the following features:
 """
 
 # This is injected automatically at release time
-__exact_version__ = 'v3.6'
+__exact_version__ = 'v3.7'
 
 import logging
 
@@ -75,18 +75,6 @@ from .models import DBSession
 logger = logging.getLogger(__name__)
 
 
-def exception_view(context, request):
-    "Log the error and return a unsuccesfull response"
-
-    from simplejson import dumps
-    from pyramid.response import Response
-
-    logger.error('Error happened serving %s: %s, %s',
-                 request.url, context.status, context)
-    return Response(dumps({'success': False, 'message': str(context)}),
-                    status=context.status, content_type='application/json')
-
-
 def favicon_view(request):
     "Serve /favicon.ico as an alias to /static/favicon.png"
 
