@@ -249,10 +249,8 @@ class Club(GloballyUnique, Base):
         simple['description'] = self.description
         if self.emblem:
             simple['emblem'] = self.emblem
-        if self.prizes:
-            simple['prizes'] = self.prizes
-        if self.couplings:
-            simple['couplings'] = self.couplings
+        simple['prizes'] = self.prizes
+        simple['couplings'] = self.couplings
         if self.nationality:
             simple['nationality'] = self.nationality
         if self.siteurl:
