@@ -605,8 +605,7 @@ Ext.define('SoL.module.Tourneys', {
     shouldDisableDeleteAction: function() {
         var grid = this;
         var sm = grid.getSelectionModel();
-        var app = grid.up().up().app.desktop.app;
-        var currentuser = app.user;
+        var currentuser = grid.up().up().app.user;
 
         if(sm.getCount() > 0) {
             var selrecs = sm.getSelection();
