@@ -606,12 +606,10 @@ class TestTourney(TestCase):
         t.prized = False
         t.assignPrizes()
         s.flush()
-        points = []
         prizes = []
         for c in t.ranking:
-            points.append(c.points)
             prizes.append(c.prize)
-        self.assertEqual(points, prizes)
+        self.assertEqual(list(range(len(prizes), 0, -1)), prizes)
 
     def test_fixed_prizes(self):
         s = models.DBSession()
@@ -657,6 +655,16 @@ class TestTourney(TestCase):
         self.assertEqual(r[2].prize, 500)
         self.assertEqual(r[3].prize, 250)
 
+    def test_centesimal_prizes(self):
+        s = models.DBSession()
+        t = s.query(models.Tourney) \
+            .filter_by(description=TourneyData.first.description).one()
+        t.championship.prizes = 'centesimal'
+        t.prized = False
+        t.assignPrizes()
+        self.assertEqual(t.ranking[0].prize, 100)
+        self.assertEqual(t.ranking[-1].prize, 1)
+
     def test_replay(self):
         s = models.DBSession()
         t = s.query(models.Tourney) \
